@@ -15,7 +15,7 @@
 
 from typing import List, Optional
 
-from ..model import Member, ReferableElement
+from ..model import Compound, ReferableElement
 from .._version import __version__
 
 
@@ -103,7 +103,7 @@ class AmbiguousReferenceError(AsciiDocError):
     def __str__(self) -> str:
         def element_to_str(element: ReferableElement) -> str:
             signature = ""
-            if isinstance(element, Member) and element.kind == "function":
+            if isinstance(element, Compound) and element.kind == "function":
                 signature = f"({', '.join(str(e.type) for e in element.params)})"
 
             return f"{element.language} {element.kind} {element.full_name}{signature}"
